**NEN-EN 9997-1+C2 - November 2017
Eurocode 7: Geotechnical design
Part 1: General rules**

The table presents a list of tables from the Eurocode 7 standards for geotechnical design, tracking their implementation status (:x: or :heavy_check_mark:)
and any pertinent remarks. The 'Object Name' column references the corresponding Python entities inside of Blueprints.

Total of 11 tables present.

| Table number | Done | Remarks | Object name |
|:-------------|:----:|:--------|:------------|
| A.1          | :x:  |         |             |
| A.2          | :x:  |         |             |
| A.3          | :x:  |         |             |
| A.4          | :x:  |         |             |
| A.5          | :x:  |         |             |
| A.6          | :x:  |         |             |
| A.7          | :x:  |         |             |
| A.8          | :x:  |         |             |
| C.1          | :x:  |         |             |
| C.2          | :x:  |         |             |
| G.1          | :x:  |         |             |
